<?php

namespace Drupal\Tests\entity_crud_alter_status_message\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Tests overall functionality.
 *
 * @group entity_crud_alter_status_message
 */
class EntityCrudAlterStatusMessageTest extends BrowserTestBase {

  use EntityCrudAlterStatusMessageTrait;

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'entity_crud_alter_status_message',
    'node',
    'taxonomy',
    'media',
    'field',
    'field_ui',
  ];

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * The admin user to use during the test.
   *
   * @var \Drupal\user\UserInterface
   */
  private $adminUser;

  /**
   * Perform initial setup tasks that run before every test method.
   */
  public function setUp(): void {
    parent::setUp();

    // Create article content type.
    $this->drupalCreateContentType([
      'type' => 'article',
      'name' => 'Article',
    ]);

    // Add vocabulary "tags".
    $this->addVocabulary(['name' => 'tags', 'vid' => 'tags']);

    // Create image media type.
    $this->drupalCreateMediaType([
      'id' => 'image',
      'label' => 'Image',
      'source' => 'file',
    ]);

    // Create the admin user.
    $this->adminUser = $this->DrupalCreateUser([
      'administer entity_crud_alter_status_message',
      'create article content',
      'create terms in tags',
      'create media',
    ]);

    // Create test create entity_crud_alter_status_message's.
    $this->createTestEntityCrudAlterStatusMessage(
      'node',
      'article',
      'default',
      'Test create node title:@label edit:@edit_link'
    );
    $this->createTestEntityCrudAlterStatusMessage(
      'taxonomy_term',
      'tags',
      'default',
      'Test create term title:@label edit:@edit_link'
    );
    $this->createTestEntityCrudAlterStatusMessage(
      'media',
      'image',
      'add',
      'Test create image title:@label edit:@edit_link'
    );

  }

  /**
   * Tests the entity_crud_alter_status_message functionality.
   */
  public function testEntityCrudAlterStatusMessage() {
    $this->drupalLogin($this->adminUser);
    $assert_session = $this->assertSession();

    // Create a test node.
    $this->drupalGet('/node/add/article');
    $edit = [
      'title[0][value]' => 'Article test node',
    ];
    $this->submitForm($edit, 'edit-submit');

    // Verify that the entity_crud_alter_status_message record is displayed.
    $assert_session->pageTextMatches(
      '/Test create node title:Article test node edit:.*\/node\/\d*\/edit/'
    );

    // Create a test term.
    $this->drupalGet('/admin/structure/taxonomy/manage/tags/add');
    $edit = [
      'name[0][value]' => 'Test term',
    ];
    $this->submitForm($edit, 'edit-submit');

    // Verify that the entity_crud_alter_status_message record is displayed.
    $assert_session->pageTextMatches(
      '/Test create term title:Test term edit:.*\/taxonomy\/term\/\d*\/edit/'
    );

    // Create a test media.
    $this->drupalGet('/media/add/image');
    $edit = [
      'name[0][value]' => 'Test image',
    ];
    $this->submitForm($edit, 'edit-submit');

    // Verify that the entity_crud_alter_status_message record is displayed.
    $assert_session->pageTextMatches(
      '/Test create image title:Test image edit:.*\/media\/\d*\/edit/'
    );

  }

}
